Module api

Module api 

Module that contains the main Emailvalidation struct

Structs

Emailvalidation
The main struct of the crate giving access to the emailvalidation.. Create a new instance of the struct with your api key as parameter.
Settings
Settings struct that contains the api key